# rmtoo-template-project

NAME
DESCRIPTION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-template-project - requirements management tool: template project

## DESCRIPTION

rmtoo comes with a complet and ready to use template project.

The template project comes with only a few requirements and topics. The environment is set up in the way, that ’make’ can be used to create mostly all available artifacts.

To start with the template project, copy the directory doc/template_project and start editing.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later